Graph 3D Internet Explorer 9 support

Graph3D uses the HTML Canvas element. This element is supported by all major browsers. The Canvas element is also supported in Internet Explorer 9 and newer. However, for Internet Exporer it is necessary to specify the doctype of the html page:

    <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
    <html>
    <head>
      <!-- ... -->
    </head>
    <body>
      <!-- ... -->
    </body>
    </html>